import {themes as prismThemes} from 'prism-react-renderer';
import type {Config} from '@docusaurus/types';
import type * as Preset from '@docusaurus/preset-classic';

const config: Config = {
  title: 'nick-slowinski.de',
  tagline: 'Pinguine sind cool.',
  favicon: 'img/favicon.ico',

  // Set the production url of your site here
  url: 'https://www.nick-slowinski.de',
  // Set the /<baseUrl>/ pathname under which your site is served
  // For GitHub pages deployment, it is often '/<projectName>/'
  baseUrl: '/',

  // GitHub pages deployment config.
  // If you aren't using GitHub pages, you don't need these.
  organizationName: 'nick-slowinski.de', // Usually your GitHub org/user name.
  projectName: 'www', // Usually your repo name.

  onBrokenLinks: 'throw',
  onBrokenMarkdownLinks: 'warn',

  // Even if you don't use internationalization, you can use this field to set
  // useful metadata like html lang. For example, if your site is Chinese, you
  // may want to replace "en" with "zh-Hans".
  i18n: {
    defaultLocale: 'de',
    locales: ['de'],
  },

  presets: [
    [
      'classic',
      {
        docs: {
          sidebarPath: './sidebars.ts',
          // Please change this to your repo.
          // Remove this to remove the "edit this page" links.
          //editUrl:
          //  'https://github.com/facebook/docusaurus/tree/main/packages/create-docusaurus/templates/shared/',
        },
        blog: {
          showReadingTime: true,
          routeBasePath: '/',
          // Please change this to your repo.
          // Remove this to remove the "edit this page" links.
          //editUrl:
          //  'https://github.com/facebook/docusaurus/tree/main/packages/create-docusaurus/templates/shared/',
        },
        theme: {
          customCss: './src/css/custom.css',
        },
      } satisfies Preset.Options,
    ],
  ],

  themeConfig: {
    // Replace with your project's social card
    image: 'img/docusaurus-social-card.jpg',
    navbar: {
      title: 'nick-slowinski.de',
      items: [
        {to: '/', label: 'Blog', position: 'left'},
        {
          type: 'docSidebar',
          sidebarId: 'tutorialSidebar',
          position: 'left',
          label: 'Wissenswertes',
        },
      ],
    },
    footer: {
      style: 'dark',
      links: [
        {
          title: 'Dienste',
          items: [
            {
              label: 'Community Forum',
              to: 'https://community.nick-slowinski.de',
            },
            {
              label: 'Drone (CI/CD)',
              to: 'https://drone.nick-slowinski.de',
            },
            {
              label: 'Forge',
              to: 'https://forge.nick-slowinski.de',
            },
            {
              label: 'Passwort-Manager',
              to: 'https://vault.nick-slowinski.de',
            },
            {
              label: 'PgAdmin4',
              to: 'https://pgadmin.nick-slowinski.de',
            },
            {
              label: 'Minio (S3)',
              to: 'https://minio.nick-slowinski.de',
            },
            {
              label: 'SSO (WIP)',
              to: 'https://accounts.nick-slowinski.de',
            },
            {
              label: 'TeamSpeak',
              to: 'ts3server://nick-slowinski.de',
            },
            {
              label: 'Weblate',
              to: 'https://weblate.nick-slowinski.de',
            },
          ],
        },
        {
          title: 'Soziales',
          items: [
            {
              label: 'X',
              href: 'https://stackoverflow.com/questions/tagged/docusaurus',
            },
            {
              label: 'Mastodon',
              href: 'https://discordapp.com/invite/docusaurus',
            },
            {
              label: 'Matrix',
              href: 'https://matrix.to/#/@nickslowinski:matrix.org',
            },
            {
              label: 'Telegram',
              href: 'https://twitter.com/docusaurus',
            },
          ],
        },
        {
          title: 'Support',
          items: [
            {
              label: 'Statusseite',
              to: 'https://status.nick-slowinski.de',
            },
            {
              label: 'E-Mail',
              to: 'mailto:support@nick-slowinski.de',
            },
            {
              label: 'Community Forum',
              to: 'https://community.nick-slowinski.de/c/support/5',
            },
          ],
        },
        {
          title: 'Rechtliches',
          items: [
            {
              label: 'Impressum',
              to: '/impressum',
            },
            {
              label: 'Datenschutzerklärung',
              href: '/datenschutzerklaerung',
            },
          ],
        },
      ],
      copyright: `Copyright © ${new Date().getFullYear()} Nick Slowinski`,
    },
    prism: {
      theme: prismThemes.github,
      darkTheme: prismThemes.dracula,
    },
  } satisfies Preset.ThemeConfig,
};

export default config;
